# clck.ru
Shortens links and protects their contents. This tool will be very useful to you if you want to get rid of long and unsafe links.

## Usage
```py
import clck
print(clck.ru("https://github.com/ttwizz"))
```